@@ -34,7 +34,7 @@ def to_txt(l, path = 'text_file.txt', overwrite = False, verbose = False):
 
     Examples :
     
-    >> rk.to_txt(var_list, './documents/vars.txt', verbose = True)
+    >>> rk.to_txt(var_list, './documents/vars.txt', verbose = True)
     File successfully written to ./documents/vars.txt
     '''
     
@@ -85,7 +85,7 @@ def read_txt(path = 'text_file.txt', verbose = False):
 
     Examples :
     
-    >> var_list = rk.read_txt('./documents/vars.txt', verbose = True)
+    >>> var_list = rk.read_txt('./documents/vars.txt', verbose = True)
     File successfully read from ./documents/vars.txt
     '''
     
@@ -97,7 +97,7 @@ def read_txt(path = 'text_file.txt', verbose = False):
             if verbose == True :
                     print(f'File successfully read from {path}')
             return l
-			
+
 
 # rk.h_size()
 def h_size(size):
@@ -115,7 +115,7 @@ def h_size(size):
 
     Examples :
     
-    >>  h_size(67108864)
+    >>>  h_size(67108864)
     '64.0 Mb'
     '''
     
@@ -125,8 +125,8 @@ def h_size(size):
         size /= 1024.0
     return "%.1f %s" % (size, 'Yb')
 
-			
-			
+
+
 # rk.get_mem()
 def get_mem(nb_objects = 10):
 
@@ -143,7 +143,7 @@ def get_mem(nb_objects = 10):
 
     Examples :
     
-    >> get_mem(5)
+    >>> get_mem(5)
     Total usage : 25.3 Gb
     
      5 largest objects :
@@ -177,7 +177,7 @@ def get_mem(nb_objects = 10):
         print(f'\n{nb_objects} largest objects :')
         for i in range(nb_objects):
             print(sorted_dict[i][0], ' : ', h_size(sorted_dict[i][1]))
-			
+
 
 # rk.csv_info()
 class csv_info:
@@ -223,12 +223,12 @@ class csv_info:
 
     Examples :
     
-    >> csv_info("table.csv").encoding
+    >>> csv_info("table.csv").encoding
     'utf-8'
     
-    >> sep, quotechar, encoding = csv_info("table.csv").parameters
-    >> df = pandas.read_csv("table.csv", sep=sep, quotechar=quotechar, encoding=encoding)
-    >> print(sep, quotechar, encoding)
+    >>> sep, quotechar, encoding = csv_info("table.csv").parameters
+    >>> df = pandas.read_csv("table.csv", sep=sep, quotechar=quotechar, encoding=encoding)
+    >>> print(sep, quotechar, encoding)
     ; " utf-8
     '''
 
@@ -276,7 +276,7 @@ encoding   : {this.encoding}
 
 
 # rk.sql_dict()
-def mysql_dict(con, db_filter = '', table_filter = '', col_filter = '', strict=False) :
+def mysql_dict(con, db_filter = '.*', table_filter = '.*', col_filter = '.*', strict=False) :
 
 #Docstring
     '''
@@ -286,13 +286,13 @@ def mysql_dict(con, db_filter = '', table_filter = '', col_filter = '', strict=F
     
     con : SQLAlchemy connectable (engine/connection) or database string URI or DBAPI2 connection (fallback mode)
     
-    db_filter : str or list of str, default is ''
+    db_filter : str or list of str, default is '.*'
         Filters on databases containing the specified regular expression(s).
     
-    table_filter : str or list of str, default is ''
+    table_filter : str or list of str, default is '.*'
         Filters on tables containing the specified regular expression(s).
   
-    column_filter : str or list of str, default is ''
+    column_filter : str or list of str, default is '.*'
         Filters on columns containing the specified regular expression(s).
         
     strict : boolean, default is False
@@ -302,12 +302,12 @@ def mysql_dict(con, db_filter = '', table_filter = '', col_filter = '', strict=F
 
     Examples :
     
-    >> temp_dict = sql_dict(con = f'mysql://{user}:{pw}@{host}:{port}', col_filter = 'price')
-    >> temp_dict.keys()
+    >>> temp_dict = sql_dict(con = f'mysql://{user}:{pw}@{host}:{port}', col_filter = 'price')
+    >>> temp_dict.keys()
     dict_keys(['products'])
-    >> temp_dict['products'].keys()
+    >>> temp_dict['products'].keys()
     dict_keys(['phones', 'laptops'])
-    >> temp_dict['products']['phones']
+    >>> temp_dict['products']['phones']
     ['price_without_tax',
      'price_with_tax']
     '''
@@ -342,4 +342,106 @@ and column_name regexp '{filter_dict["col_filter"]}'
         if len(db_dict) != 0:
             con_dict[db] = db_dict
     
-    return con_dict
\ No newline at end of file
+    return con_dict
+
+
+# rk.humantime()
+def humantime(ms):
+
+# Docstring
+    """
+    Converts timespan in milliseconds to a humanly readable string.
+    
+    --------------
+    
+    ms : int or float
+        Time in milliseconds
+
+    --------------
+
+    Examples :
+    
+    >>> humantime(194159)
+    '3 min, 14 sec, 159 ms'
+    """
+    
+    time_dict = {'ms' : ms}
+
+    time_dict['sec'] = time_dict['ms'] // 1000
+    time_dict['ms'] -= 1000 * time_dict['sec']
+    time_dict['min'] = time_dict['sec'] // 60
+    time_dict['sec'] -= 60 * time_dict['min']
+    time_dict['hs'] = time_dict['min'] // 60
+    time_dict['min'] -= 60 * time_dict['hs']
+    time_dict['days'] = time_dict['hs'] // 24
+    time_dict['hs'] -= 24 * time_dict['days']
+    
+    time_str = ""
+    for key in reversed([key for key in time_dict.keys()]):
+        if time_dict[key] != 0 :
+            time_str = f"{time_str}{time_dict[key]} {key}, "
+            
+    time_str = time_str.rstrip(', ')
+    
+    return time_str
+	
+
+# rk.timer.start() / rk.timer.end()
+class timer:
+    # Docstring
+    """
+    Class for measuring elapsed time.
+    Contains the rk.timer.start() function to start counting, and the rk.timer.end() to print out the timespan.
+
+    --------------
+    
+    Example :
+    >>> rk.timer.start()
+    >>> time.sleep(2)
+    >>> rk.timer.end("Sleep time")
+    [Sleep time] : 2 sec, 2 ms
+    """
+
+    def __init__(self):
+        return None
+
+    def start():
+    # Docstring
+        """
+        Saves the time as a global variable.
+
+        --------------
+
+        Example :
+        >>> rk.timer.start()
+        >>> time.sleep(2)
+        >>> rk.timer.end("Sleep time")
+        [Sleep time] : 2 sec, 2 ms
+        """
+        
+        global start_time
+        start_time = time.time()
+        return None
+            
+    def end(step = "Execution time"):
+    # Docstring
+        """
+        Prints out the time elapsed since the rk.timer.start() call.
+        
+        --------------
+        
+        step : str or int, default "  time"
+
+        --------------
+
+        Example :
+        >>> rk.timer.start()
+        >>> time.sleep(2)
+        >>> rk.timer.end("Sleep time")
+        [Sleep time] : 2 sec, 2 ms
+        """
+        global start_time
+        try :
+            print(f"[{step}] : {humantime(round((time.time() - start_time)*1000))}")
+        except NameError:
+            print('No starttime')
\ No newline at end of file
